@@ -76,27 +76,119 @@ class PreAggregation(BaseModel):
     build_range_start: str | None = Field(None, description="SQL expression for start of data range to aggregate")
     build_range_end: str | None = Field(None, description="SQL expression for end of data range to aggregate")
 
-    def get_table_name(self, model_name: str) -> str:
+    def get_table_name(self, model_name: str, database: str | None = None, schema: str | None = None) -> str:
         """Generate the physical table name for this pre-aggregation.
 
         Args:
             model_name: Name of the base model
+            database: Optional database name (for cross-database queries)
+            schema: Optional schema name (for schema-qualified tables)
 
         Returns:
-            Table name in format: {model_name}_preagg_{preagg_name}
+            Qualified table name in format: [database.][schema.]{model_name}_preagg_{preagg_name}
         """
-        return f"{model_name}_preagg_{self.name}"
+        table_name = f"{model_name}_preagg_{self.name}"
+
+        # Build fully qualified name if database/schema provided
+        if schema:
+            table_name = f"{schema}.{table_name}"
+        if database:
+            table_name = f"{database}.{table_name}"
+
+        return table_name
+
+    def generate_materialization_sql(self, model: Any) -> str:
+        """Generate SQL to materialize this pre-aggregation.
+
+        Args:
+            model: The Model object that owns this pre-aggregation
+
+        Returns:
+            SQL query to create/populate the pre-aggregation table
+
+        Example:
+            >>> preagg = PreAggregation(
+            ...     name="daily",
+            ...     measures=["count", "revenue"],
+            ...     dimensions=["status"],
+            ...     time_dimension="created_at",
+            ...     granularity="day"
+            ... )
+            >>> sql = preagg.generate_materialization_sql(model)
+            # Returns:
+            # SELECT
+            #   DATE_TRUNC('day', created_at) as created_at_day,
+            #   status,
+            #   COUNT(*) as count_raw,
+            #   SUM(amount) as revenue_raw
+            # FROM orders
+            # GROUP BY 1, 2
+        """
+        select_exprs = []
+        group_by_positions = []
+        pos = 1
+
+        # Add time dimension with granularity
+        if self.time_dimension and self.granularity:
+            time_dim = model.get_dimension(self.time_dimension)
+            if time_dim:
+                col_name = f"{self.time_dimension}_{self.granularity}"
+                select_exprs.append(f"DATE_TRUNC('{self.granularity}', {time_dim.sql_expr}) as {col_name}")
+                group_by_positions.append(str(pos))
+                pos += 1
+
+        # Add dimensions
+        if self.dimensions:
+            for dim_name in self.dimensions:
+                dim = model.get_dimension(dim_name)
+                if dim:
+                    select_exprs.append(f"{dim.sql_expr} as {dim_name}")
+                    group_by_positions.append(str(pos))
+                    pos += 1
+
+        # Add measures (aggregations)
+        if self.measures:
+            for measure_name in self.measures:
+                measure = model.get_metric(measure_name)
+                if measure:
+                    # Generate aggregation expression
+                    agg_type = measure.agg.upper()
+                    if agg_type == "COUNT" and not measure.sql:
+                        # COUNT(*) case
+                        select_exprs.append(f"COUNT(*) as {measure_name}_raw")
+                    elif agg_type == "COUNT_DISTINCT":
+                        select_exprs.append(f"COUNT(DISTINCT {measure.sql_expr}) as {measure_name}_raw")
+                    else:
+                        select_exprs.append(f"{agg_type}({measure.sql_expr}) as {measure_name}_raw")
+
+        # Build FROM clause
+        if model.sql:
+            from_clause = f"({model.sql}) AS t"
+        else:
+            from_clause = model.table
+
+        # Build SQL
+        select_str = ",\n  ".join(select_exprs)
+        group_by_str = ", ".join(group_by_positions)
+
+        sql = f"""SELECT
+  {select_str}
+FROM {from_clause}
+GROUP BY {group_by_str}"""
+
+        return sql
 
     def refresh(
         self,
         connection: Any,
         source_sql: str,
         table_name: str,
-        mode: Literal["full", "incremental", "merge"] | None = None,
+        mode: Literal["full", "incremental", "merge", "engine"] | None = None,
         watermark_column: str | None = None,
         lookback: str | None = None,
         from_watermark: Any | None = None,
         to_watermark: Any | None = None,
+        dialect: str | None = None,
     ) -> "RefreshResult":
         """Refresh pre-aggregation (STATELESS).
 
@@ -233,6 +325,12 @@ class PreAggregation(BaseModel):
             rows_inserted, rows_updated, new_watermark = self._refresh_merge(
                 connection, source_sql, table_name, watermark_column, lookback, from_watermark, to_watermark
             )
+        elif mode == "engine":
+            if not dialect:
+                raise ValueError("dialect required for engine refresh mode")
+            rows_inserted, rows_updated, new_watermark = self._refresh_engine(
+                connection, source_sql, table_name, dialect
+            )
         else:
             raise ValueError(f"Invalid refresh mode: {mode}")
 
@@ -443,6 +541,146 @@ class PreAggregation(BaseModel):
 
         return (-1, -1, new_watermark)
 
+    def _validate_sql_for_engine(self, source_sql: str, dialect: str) -> tuple[bool, str | None]:
+        """Validate SQL is compatible with database-native materialized views.
+
+        Args:
+            source_sql: SQL query to validate
+            dialect: Database dialect (snowflake, clickhouse, bigquery)
+
+        Returns:
+            (is_valid, error_message)
+        """
+        import sqlglot
+
+        # Parse SQL to check for unsupported features
+        try:
+            parsed = sqlglot.parse_one(source_sql, dialect=dialect)
+        except Exception as e:
+            return (False, f"Failed to parse SQL: {e}")
+
+        # Check for window functions (not supported in most materialized views)
+        for node in parsed.walk():
+            if isinstance(node, sqlglot.exp.Window):
+                return (False, "Window functions not supported in materialized views")
+
+        # Dialect-specific restrictions
+        if dialect == "snowflake":
+            # Snowflake DYNAMIC TABLES don't support certain features
+            for node in parsed.walk():
+                if isinstance(node, sqlglot.exp.Join):
+                    # Joins are supported but with restrictions
+                    pass  # Allow for now
+                if isinstance(node, sqlglot.exp.Subquery):
+                    # Subqueries in SELECT are restricted
+                    if node.parent and isinstance(node.parent, sqlglot.exp.Select):
+                        return (False, "Scalar subqueries not fully supported in Snowflake DYNAMIC TABLES")
+
+        elif dialect == "clickhouse":
+            # ClickHouse materialized views have specific restrictions
+            # They must be simple aggregations
+            pass  # Allow for now
+
+        elif dialect == "bigquery":
+            # BigQuery materialized views don't support certain features
+            for node in parsed.walk():
+                if isinstance(node, sqlglot.exp.Join):
+                    join_type = node.args.get("kind", "")
+                    if join_type and join_type.upper() not in ["INNER", "LEFT", "RIGHT", "FULL"]:
+                        return (False, f"BigQuery materialized views don't support {join_type} joins")
+
+        return (True, None)
+
+    def _refresh_engine(
+        self,
+        connection: Any,
+        source_sql: str,
+        table_name: str,
+        dialect: str,
+    ) -> tuple[int, int, Any | None]:
+        """Execute refresh using database-native materialized views.
+
+        Args:
+            connection: Database connection
+            source_sql: SQL query to materialize
+            table_name: Target table/view name
+            dialect: Database dialect (snowflake, clickhouse, bigquery)
+
+        Returns:
+            (rows_inserted, rows_updated, new_watermark)
+        """
+        # Validate SQL is compatible with engine
+        is_valid, error_msg = self._validate_sql_for_engine(source_sql, dialect)
+        if not is_valid:
+            raise ValueError(f"SQL not compatible with {dialect} materialized views: {error_msg}")
+
+        # Generate database-specific DDL
+        if dialect == "snowflake":
+            # Snowflake DYNAMIC TABLE
+            # Get refresh interval from config
+            refresh_interval = "1 HOUR"  # Default
+            if self.refresh_key and self.refresh_key.every:
+                # Convert "1 hour" to "1 HOUR"
+                refresh_interval = self.refresh_key.every.replace(" ", " ").upper()
+
+            ddl = f"""
+CREATE OR REPLACE DYNAMIC TABLE {table_name}
+TARGET_LAG = '{refresh_interval}'
+WAREHOUSE = 'COMPUTE_WH'
+AS
+{source_sql}
+            """.strip()
+
+        elif dialect == "clickhouse":
+            # ClickHouse MATERIALIZED VIEW
+            # Extract target table from view name
+            target_table = f"{table_name}_data"
+
+            ddl = f"""
+CREATE MATERIALIZED VIEW IF NOT EXISTS {table_name}
+TO {target_table}
+AS
+{source_sql}
+            """.strip()
+
+        elif dialect == "bigquery":
+            # BigQuery MATERIALIZED VIEW
+            # Get refresh interval from config
+            enable_refresh = "true"
+            refresh_interval_minutes = 60  # Default 1 hour
+
+            if self.refresh_key and self.refresh_key.every:
+                # Parse interval
+                parts = self.refresh_key.every.split()
+                if len(parts) == 2:
+                    value, unit = parts
+                    value = int(value)
+                    if "minute" in unit.lower():
+                        refresh_interval_minutes = value
+                    elif "hour" in unit.lower():
+                        refresh_interval_minutes = value * 60
+                    elif "day" in unit.lower():
+                        refresh_interval_minutes = value * 60 * 24
+
+            ddl = f"""
+CREATE MATERIALIZED VIEW IF NOT EXISTS {table_name}
+OPTIONS(
+  enable_refresh = {enable_refresh},
+  refresh_interval_minutes = {refresh_interval_minutes}
+)
+AS
+{source_sql}
+            """.strip()
+
+        else:
+            raise ValueError(f"Unsupported dialect for engine mode: {dialect}")
+
+        # Execute DDL
+        connection.execute(ddl)
+
+        # Engine mode: rows are managed by database, return -1
+        return (-1, -1, None)
+
 
 @dataclass
 class RefreshResult:
@@ -451,7 +689,7 @@ class RefreshResult:
     External orchestrators should store the new_watermark for the next refresh.
     """
 
-    mode: Literal["full", "incremental", "merge"]
+    mode: Literal["full", "incremental", "merge", "engine"]
     rows_inserted: int  # -1 if unknown
     rows_updated: int  # -1 if unknown
     new_watermark: Any | None  # Orchestrator stores this for next run
